@@ -1,4 +1,4 @@
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 import requests
 
@@ -9,11 +9,28 @@ from ...models.osidb_api_v1_trackers_list_response_200 import (
 from ...models.osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
 from ...types import UNSET, Response, Unset
 
+QUERY_PARAMS = {
+    "exclude_fields": List[str],
+    "external_system_id": str,
+    "include_fields": List[str],
+    "include_meta_attr": List[str],
+    "limit": int,
+    "offset": int,
+    "ps_update_stream": str,
+    "resolution": str,
+    "status": str,
+    "type": OsidbApiV1TrackersListType,
+    "uuid": str,
+}
+
 
 def _get_kwargs(
     *,
     client: AuthenticatedClient,
+    exclude_fields: Union[Unset, None, List[str]] = UNSET,
     external_system_id: Union[Unset, None, str] = UNSET,
+    include_fields: Union[Unset, None, List[str]] = UNSET,
+    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     ps_update_stream: Union[Unset, None, str] = UNSET,
@@ -28,13 +45,37 @@ def _get_kwargs(
 
     headers: Dict[str, Any] = client.get_headers()
 
+    json_exclude_fields: Union[Unset, None, List[str]] = UNSET
+    if not isinstance(exclude_fields, Unset):
+        if exclude_fields is None:
+            json_exclude_fields = None
+        else:
+            json_exclude_fields = exclude_fields
+
+    json_include_fields: Union[Unset, None, List[str]] = UNSET
+    if not isinstance(include_fields, Unset):
+        if include_fields is None:
+            json_include_fields = None
+        else:
+            json_include_fields = include_fields
+
+    json_include_meta_attr: Union[Unset, None, List[str]] = UNSET
+    if not isinstance(include_meta_attr, Unset):
+        if include_meta_attr is None:
+            json_include_meta_attr = None
+        else:
+            json_include_meta_attr = include_meta_attr
+
     json_type: Union[Unset, None, str] = UNSET
     if not isinstance(type, Unset):
 
         json_type = OsidbApiV1TrackersListType(type).value if type else None
 
     params: Dict[str, Any] = {
+        "exclude_fields": json_exclude_fields,
         "external_system_id": external_system_id,
+        "include_fields": json_include_fields,
+        "include_meta_attr": json_include_meta_attr,
         "limit": limit,
         "offset": offset,
         "ps_update_stream": ps_update_stream,
@@ -81,7 +122,10 @@ def _build_response(
 def sync_detailed(
     *,
     client: AuthenticatedClient,
+    exclude_fields: Union[Unset, None, List[str]] = UNSET,
     external_system_id: Union[Unset, None, str] = UNSET,
+    include_fields: Union[Unset, None, List[str]] = UNSET,
+    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     ps_update_stream: Union[Unset, None, str] = UNSET,
@@ -92,7 +136,10 @@ def sync_detailed(
 ) -> Response[OsidbApiV1TrackersListResponse200]:
     kwargs = _get_kwargs(
         client=client,
+        exclude_fields=exclude_fields,
         external_system_id=external_system_id,
+        include_fields=include_fields,
+        include_meta_attr=include_meta_attr,
         limit=limit,
         offset=offset,
         ps_update_stream=ps_update_stream,
@@ -116,7 +163,10 @@ def sync_detailed(
 def sync(
     *,
     client: AuthenticatedClient,
+    exclude_fields: Union[Unset, None, List[str]] = UNSET,
     external_system_id: Union[Unset, None, str] = UNSET,
+    include_fields: Union[Unset, None, List[str]] = UNSET,
+    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
     limit: Union[Unset, None, int] = UNSET,
     offset: Union[Unset, None, int] = UNSET,
     ps_update_stream: Union[Unset, None, str] = UNSET,
@@ -129,7 +179,10 @@ def sync(
 
     return sync_detailed(
         client=client,
+        exclude_fields=exclude_fields,
         external_system_id=external_system_id,
+        include_fields=include_fields,
+        include_meta_attr=include_meta_attr,
         limit=limit,
         offset=offset,
         ps_update_stream=ps_update_stream,
