@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
+from ..types import OSIDBModel
+
 T = TypeVar("T", bound="CollectorsApiV1StatusRetrieveResponse200CollectorsItemError")
 
 
 @attr.s(auto_attribs=True)
-class CollectorsApiV1StatusRetrieveResponse200CollectorsItemError:
+class CollectorsApiV1StatusRetrieveResponse200CollectorsItemError(OSIDBModel):
     """ """
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -28,6 +30,10 @@ class CollectorsApiV1StatusRetrieveResponse200CollectorsItemError:
         )
         return collectors_api_v1_status_retrieve_response_200_collectors_item_error
 
+    @staticmethod
+    def get_fields():
+        return {}
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
