@@ -4,13 +4,13 @@ from typing import Any, Dict, List, Type, TypeVar, Union
 import attr
 from dateutil.parser import isoparse
 
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="CollectorsHealthyRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class CollectorsHealthyRetrieveResponse200:
+class CollectorsHealthyRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -67,6 +67,15 @@ class CollectorsHealthyRetrieveResponse200:
         collectors_healthy_retrieve_response_200.additional_properties = d
         return collectors_healthy_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "env": str,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
