@@ -4,13 +4,13 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 import attr
 from dateutil.parser import isoparse
 
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="CollectorsRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class CollectorsRetrieveResponse200:
+class CollectorsRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -77,6 +77,16 @@ class CollectorsRetrieveResponse200:
         collectors_retrieve_response_200.additional_properties = d
         return collectors_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "env": str,
+            "index": List[str],
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
