@@ -6,13 +6,13 @@ from dateutil.parser import isoparse
 
 from ..models.comment_meta_attr import CommentMetaAttr
 from ..models.comment_type_enum import CommentTypeEnum
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="Comment")
 
 
 @attr.s(auto_attribs=True)
-class Comment:
+class Comment(OSIDBModel):
     """FlawComment serializer"""
 
     uuid: str
@@ -114,6 +114,18 @@ class Comment:
         comment.additional_properties = d
         return comment
 
+    @staticmethod
+    def get_fields():
+        return {
+            "uuid": str,
+            "external_system_id": str,
+            "created_dt": datetime.datetime,
+            "updated_dt": datetime.datetime,
+            "type": CommentTypeEnum,
+            "order": int,
+            "meta_attr": CommentMetaAttr,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
