@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
+from ..types import OSIDBModel
+
 T = TypeVar("T", bound="ExploitsApiV1CveMapRetrieveResponse200Cves")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1CveMapRetrieveResponse200Cves:
+class ExploitsApiV1CveMapRetrieveResponse200Cves(OSIDBModel):
     """ """
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -26,6 +28,10 @@ class ExploitsApiV1CveMapRetrieveResponse200Cves:
         exploits_api_v1_cve_map_retrieve_response_200_cves.additional_properties = d
         return exploits_api_v1_cve_map_retrieve_response_200_cves
 
+    @staticmethod
+    def get_fields():
+        return {}
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
