@@ -13,13 +13,13 @@ from ..models.exploits_api_v1_report_date_retrieve_response_200_no_action_item i
 from ..models.exploits_api_v1_report_date_retrieve_response_200_not_relevant_item import (
     ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem,
 )
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="ExploitsApiV1ReportDateRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1ReportDateRetrieveResponse200:
+class ExploitsApiV1ReportDateRetrieveResponse200(OSIDBModel):
     """ """
 
     action_required: Union[
@@ -189,6 +189,24 @@ class ExploitsApiV1ReportDateRetrieveResponse200:
         exploits_api_v1_report_date_retrieve_response_200.additional_properties = d
         return exploits_api_v1_report_date_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "action_required": List[
+                ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem
+            ],
+            "cutoff_date": str,
+            "dt": datetime.datetime,
+            "env": str,
+            "evaluated_cves": int,
+            "no_action": List[ExploitsApiV1ReportDateRetrieveResponse200NoActionItem],
+            "not_relevant": List[
+                ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem
+            ],
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
