@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
+from ..types import OSIDBModel
+
 T = TypeVar("T", bound="ExploitsApiV1ReportDateRetrieveResponse200NoActionItem")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1ReportDateRetrieveResponse200NoActionItem:
+class ExploitsApiV1ReportDateRetrieveResponse200NoActionItem(OSIDBModel):
     """ """
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -28,6 +30,10 @@ class ExploitsApiV1ReportDateRetrieveResponse200NoActionItem:
         )
         return exploits_api_v1_report_date_retrieve_response_200_no_action_item
 
+    @staticmethod
+    def get_fields():
+        return {}
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
