@@ -7,13 +7,13 @@ from dateutil.parser import isoparse
 from ..models.exploits_api_v1_report_explanations_retrieve_response_200_explanations_item import (
     ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem,
 )
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="ExploitsApiV1ReportExplanationsRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1ReportExplanationsRetrieveResponse200:
+class ExploitsApiV1ReportExplanationsRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -112,6 +112,19 @@ class ExploitsApiV1ReportExplanationsRetrieveResponse200:
         )
         return exploits_api_v1_report_explanations_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "env": str,
+            "explanations": List[
+                ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem
+            ],
+            "page_size": int,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
