@@ -7,13 +7,13 @@ from dateutil.parser import isoparse
 from ..models.exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item import (
     ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem,
 )
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="ExploitsApiV1ReportPendingRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class ExploitsApiV1ReportPendingRetrieveResponse200:
+class ExploitsApiV1ReportPendingRetrieveResponse200(OSIDBModel):
     """ """
 
     dt: Union[Unset, datetime.datetime] = UNSET
@@ -110,6 +110,19 @@ class ExploitsApiV1ReportPendingRetrieveResponse200:
         exploits_api_v1_report_pending_retrieve_response_200.additional_properties = d
         return exploits_api_v1_report_pending_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "dt": datetime.datetime,
+            "env": str,
+            "pending_actions": List[
+                ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem
+            ],
+            "pending_actions_count": int,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
