@@ -6,17 +6,18 @@ from dateutil.parser import isoparse
 
 from ..models.meta_meta_attr import MetaMetaAttr
 from ..models.meta_type_enum import MetaTypeEnum
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="Meta")
 
 
 @attr.s(auto_attribs=True)
-class Meta:
+class Meta(OSIDBModel):
     """FlawMeta serializer"""
 
     uuid: str
     type: MetaTypeEnum
+    embargoed: bool
     created_dt: datetime.datetime
     updated_dt: datetime.datetime
     meta_attr: Union[Unset, MetaMetaAttr] = UNSET
@@ -29,6 +30,7 @@ class Meta:
 
             type = MetaTypeEnum(self.type).value
 
+        embargoed = self.embargoed
         created_dt: str = UNSET
         if not isinstance(self.created_dt, Unset):
             created_dt = self.created_dt.isoformat()
@@ -47,6 +49,8 @@ class Meta:
             field_dict["uuid"] = uuid
         if type is not UNSET:
             field_dict["type"] = type
+        if embargoed is not UNSET:
+            field_dict["embargoed"] = embargoed
         if created_dt is not UNSET:
             field_dict["created_dt"] = created_dt
         if updated_dt is not UNSET:
@@ -68,6 +72,8 @@ class Meta:
         else:
             type = MetaTypeEnum(_type)
 
+        embargoed = d.pop("embargoed", UNSET)
+
         _created_dt = d.pop("created_dt", UNSET)
         created_dt: datetime.datetime
         if isinstance(_created_dt, Unset):
@@ -92,6 +98,7 @@ class Meta:
         meta = cls(
             uuid=uuid,
             type=type,
+            embargoed=embargoed,
             created_dt=created_dt,
             updated_dt=updated_dt,
             meta_attr=meta_attr,
@@ -100,6 +107,17 @@ class Meta:
         meta.additional_properties = d
         return meta
 
+    @staticmethod
+    def get_fields():
+        return {
+            "uuid": str,
+            "type": MetaTypeEnum,
+            "embargoed": bool,
+            "created_dt": datetime.datetime,
+            "updated_dt": datetime.datetime,
+            "meta_attr": MetaMetaAttr,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
