@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Optional, Type, TypeVar
 
 import attr
 
+from ..types import OSIDBModel
+
 T = TypeVar("T", bound="MetaMetaAttr")
 
 
 @attr.s(auto_attribs=True)
-class MetaMetaAttr:
+class MetaMetaAttr(OSIDBModel):
     """ """
 
     additional_properties: Dict[str, Optional[str]] = attr.ib(init=False, factory=dict)
@@ -26,6 +28,10 @@ class MetaMetaAttr:
         meta_meta_attr.additional_properties = d
         return meta_meta_attr
 
+    @staticmethod
+    def get_fields():
+        return {}
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
