@@ -5,19 +5,19 @@ import attr
 from dateutil.parser import isoparse
 
 from ..models.affect_meta_attr import AffectMetaAttr
-from ..models.affect_resolution_enum import AffectResolutionEnum
 from ..models.affect_type_enum import AffectTypeEnum
 from ..models.affectedness_enum import AffectednessEnum
 from ..models.blank_enum import BlankEnum
 from ..models.impact_enum import ImpactEnum
+from ..models.resolution_3_ac_enum import Resolution3AcEnum
 from ..models.tracker import Tracker
-from ..types import UNSET, Unset
+from ..types import UNSET, OSIDBModel, Unset
 
 T = TypeVar("T", bound="OsidbApiV1AffectsRetrieveResponse200")
 
 
 @attr.s(auto_attribs=True)
-class OsidbApiV1AffectsRetrieveResponse200:
+class OsidbApiV1AffectsRetrieveResponse200(OSIDBModel):
     """ """
 
     uuid: str
@@ -26,12 +26,13 @@ class OsidbApiV1AffectsRetrieveResponse200:
     trackers: List[Tracker]
     meta_attr: AffectMetaAttr
     delegated_resolution: str
+    embargoed: bool
     created_dt: datetime.datetime
     updated_dt: datetime.datetime
     flaw: Optional[str]
     type: Union[Unset, AffectTypeEnum] = UNSET
     affectedness: Union[AffectednessEnum, BlankEnum, Unset] = UNSET
-    resolution: Union[AffectResolutionEnum, BlankEnum, Unset] = UNSET
+    resolution: Union[BlankEnum, Resolution3AcEnum, Unset] = UNSET
     impact: Union[BlankEnum, ImpactEnum, Unset] = UNSET
     cvss2: Union[Unset, str] = UNSET
     cvss2_score: Union[Unset, None, float] = UNSET
@@ -62,6 +63,7 @@ class OsidbApiV1AffectsRetrieveResponse200:
             meta_attr = self.meta_attr.to_dict()
 
         delegated_resolution = self.delegated_resolution
+        embargoed = self.embargoed
         created_dt: str = UNSET
         if not isinstance(self.created_dt, Unset):
             created_dt = self.created_dt.isoformat()
@@ -94,11 +96,11 @@ class OsidbApiV1AffectsRetrieveResponse200:
         resolution: Union[Unset, str]
         if isinstance(self.resolution, Unset):
             resolution = UNSET
-        elif isinstance(self.resolution, AffectResolutionEnum):
+        elif isinstance(self.resolution, Resolution3AcEnum):
             resolution = UNSET
             if not isinstance(self.resolution, Unset):
 
-                resolution = AffectResolutionEnum(self.resolution).value
+                resolution = Resolution3AcEnum(self.resolution).value
 
         else:
             resolution = UNSET
@@ -147,6 +149,8 @@ class OsidbApiV1AffectsRetrieveResponse200:
             field_dict["meta_attr"] = meta_attr
         if delegated_resolution is not UNSET:
             field_dict["delegated_resolution"] = delegated_resolution
+        if embargoed is not UNSET:
+            field_dict["embargoed"] = embargoed
         if created_dt is not UNSET:
             field_dict["created_dt"] = created_dt
         if updated_dt is not UNSET:
@@ -213,6 +217,8 @@ class OsidbApiV1AffectsRetrieveResponse200:
 
         delegated_resolution = d.pop("delegated_resolution", UNSET)
 
+        embargoed = d.pop("embargoed", UNSET)
+
         _created_dt = d.pop("created_dt", UNSET)
         created_dt: datetime.datetime
         if isinstance(_created_dt, Unset):
@@ -269,18 +275,18 @@ class OsidbApiV1AffectsRetrieveResponse200:
 
         def _parse_resolution(
             data: object,
-        ) -> Union[AffectResolutionEnum, BlankEnum, Unset]:
+        ) -> Union[BlankEnum, Resolution3AcEnum, Unset]:
             if isinstance(data, Unset):
                 return data
             try:
                 if not isinstance(data, str):
                     raise TypeError()
                 _resolution_type_0 = data
-                resolution_type_0: Union[Unset, AffectResolutionEnum]
+                resolution_type_0: Union[Unset, Resolution3AcEnum]
                 if isinstance(_resolution_type_0, Unset):
                     resolution_type_0 = UNSET
                 else:
-                    resolution_type_0 = AffectResolutionEnum(_resolution_type_0)
+                    resolution_type_0 = Resolution3AcEnum(_resolution_type_0)
 
                 return resolution_type_0
             except:  # noqa: E722
@@ -355,6 +361,7 @@ class OsidbApiV1AffectsRetrieveResponse200:
             trackers=trackers,
             meta_attr=meta_attr,
             delegated_resolution=delegated_resolution,
+            embargoed=embargoed,
             created_dt=created_dt,
             updated_dt=updated_dt,
             flaw=flaw,
@@ -375,6 +382,33 @@ class OsidbApiV1AffectsRetrieveResponse200:
         osidb_api_v1_affects_retrieve_response_200.additional_properties = d
         return osidb_api_v1_affects_retrieve_response_200
 
+    @staticmethod
+    def get_fields():
+        return {
+            "uuid": str,
+            "ps_module": str,
+            "ps_component": str,
+            "trackers": List[Tracker],
+            "meta_attr": AffectMetaAttr,
+            "delegated_resolution": str,
+            "embargoed": bool,
+            "created_dt": datetime.datetime,
+            "updated_dt": datetime.datetime,
+            "flaw": str,
+            "type": AffectTypeEnum,
+            "affectedness": Union[AffectednessEnum, BlankEnum],
+            "resolution": Union[BlankEnum, Resolution3AcEnum],
+            "impact": Union[BlankEnum, ImpactEnum],
+            "cvss2": str,
+            "cvss2_score": float,
+            "cvss3": str,
+            "cvss3_score": float,
+            "dt": datetime.datetime,
+            "env": str,
+            "revision": str,
+            "version": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
