@@ -2,11 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
+from ..types import OSIDBModel
+
 T = TypeVar("T", bound="OsidbApiV1StatusRetrieveResponse200OsidbService")
 
 
 @attr.s(auto_attribs=True)
-class OsidbApiV1StatusRetrieveResponse200OsidbService:
+class OsidbApiV1StatusRetrieveResponse200OsidbService(OSIDBModel):
     """ """
 
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -28,6 +30,10 @@ class OsidbApiV1StatusRetrieveResponse200OsidbService:
         )
         return osidb_api_v1_status_retrieve_response_200_osidb_service
 
+    @staticmethod
+    def get_fields():
+        return {}
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
