@@ -2,13 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-from ..types import UNSET
+from ..types import UNSET, OSIDBModel
 
 T = TypeVar("T", bound="TokenObtainPair")
 
 
 @attr.s(auto_attribs=True)
-class TokenObtainPair:
+class TokenObtainPair(OSIDBModel):
     """ """
 
     username: str
@@ -97,6 +97,15 @@ class TokenObtainPair:
         token_obtain_pair.additional_properties = d
         return token_obtain_pair
 
+    @staticmethod
+    def get_fields():
+        return {
+            "username": str,
+            "password": str,
+            "access": str,
+            "refresh": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
