@@ -2,13 +2,13 @@ from typing import Any, Dict, List, Type, TypeVar
 
 import attr
 
-from ..types import UNSET
+from ..types import UNSET, OSIDBModel
 
 T = TypeVar("T", bound="TokenRefresh")
 
 
 @attr.s(auto_attribs=True)
-class TokenRefresh:
+class TokenRefresh(OSIDBModel):
     """ """
 
     access: str
@@ -69,6 +69,13 @@ class TokenRefresh:
         token_refresh.additional_properties = d
         return token_refresh
 
+    @staticmethod
+    def get_fields():
+        return {
+            "access": str,
+            "refresh": str,
+        }
+
     @property
     def additional_keys(self) -> List[str]:
         return list(self.additional_properties.keys())
